[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [54888] trunk/blender/source/blender/ editors/space_view3d/view3d_header.c: Add: [#34443] Ability to set ' Pivot Center for rotation/scale' missing in weight paint mode

Gaia Clary gaia.clary at machinimatrix.org
Tue Feb 26 19:35:17 CET 2013


Revision: 54888
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=54888
Author:   gaiaclary
Date:     2013-02-26 18:35:16 +0000 (Tue, 26 Feb 2013)
Log Message:
-----------
Add: [#34443] Ability to set 'Pivot Center for rotation/scale' missing in weight paint mode

Modified Paths:
--------------
    trunk/blender/source/blender/editors/space_view3d/view3d_header.c

Modified: trunk/blender/source/blender/editors/space_view3d/view3d_header.c
===================================================================
--- trunk/blender/source/blender/editors/space_view3d/view3d_header.c	2013-02-26 18:15:51 UTC (rev 54887)
+++ trunk/blender/source/blender/editors/space_view3d/view3d_header.c	2013-02-26 18:35:16 UTC (rev 54888)
@@ -453,6 +453,13 @@
 	uiItemR(layout, &v3dptr, "viewport_shade", UI_ITEM_R_ICON_ONLY, "", ICON_NONE);
 
 	if (obedit == NULL && is_paint) {
+
+		if (ob->mode & OB_MODE_WEIGHT_PAINT) {
+			/* Only for Weight Paint. makes no sense in other paint modes. */
+			row = uiLayoutRow(layout, TRUE);
+			uiItemR(row, &v3dptr, "pivot_point", UI_ITEM_R_ICON_ONLY, "", ICON_NONE);
+		}
+
 		/* Manipulators aren't used in paint modes */
 		if (!ELEM(ob->mode, OB_MODE_SCULPT, OB_MODE_PARTICLE_EDIT)) {
 			/* masks aren't used for sculpt and particle painting */
@@ -476,7 +483,9 @@
 		uiItemR(row, &v3dptr, "pivot_point", UI_ITEM_R_ICON_ONLY, "", ICON_NONE);
 
 		/* pose/object only however we want to allow in weight paint mode too
 		 * so don't be totally strict and just check not-editmode for now */
 		if (obedit == NULL) {
 			uiItemR(row, &v3dptr, "use_pivot_point_align", UI_ITEM_R_ICON_ONLY, "", ICON_NONE);
 		}
@@ -476,7 +483,9 @@
 
 		/* pose/object only however we want to allow in weight paint mode too
-		 * so don't be totally strict and just check not-editmode for now */
+		 * so don't be totally strict and just check not-editmode for now 
+		 * XXX We never get here when we are in Weight Paint mode
+		 */
 		if (obedit == NULL) {
 			uiItemR(row, &v3dptr, "use_pivot_point_align", UI_ITEM_R_ICON_ONLY, "", ICON_NONE);




More information about the Bf-blender-cvs mailing list